==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/quicksight_data_source/QuicksightDataSourceParametersS3.java <==
package com.hashicorp.cdktf.providers.aws.quicksight_data_source;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:55.147Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.quicksightDataSource.QuicksightDataSourceParametersS3")
@software.amazon.jsii.Jsii.Proxy(QuicksightDataSourceParametersS3.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface QuicksightDataSourceParametersS3 extends software.amazon.jsii.JsiiSerializable {

    /**
     * manifest_file_location block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#manifest_file_location QuicksightDataSource#manifest_file_location}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.quicksight_data_source.QuicksightDataSourceParametersS3ManifestFileLocation getManifestFileLocation();

    /**
     * @return a {@link Builder} of {@link QuicksightDataSourceParametersS3}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link QuicksightDataSourceParametersS3}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<QuicksightDataSourceParametersS3> {
        com.hashicorp.cdktf.providers.aws.quicksight_data_source.QuicksightDataSourceParametersS3ManifestFileLocation manifestFileLocation;

        /**
         * Sets the value of {@link QuicksightDataSourceParametersS3#getManifestFileLocation}
         * @param manifestFileLocation manifest_file_location block. This parameter is required.
         *                             Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#manifest_file_location QuicksightDataSource#manifest_file_location}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder manifestFileLocation(com.hashicorp.cdktf.providers.aws.quicksight_data_source.QuicksightDataSourceParametersS3ManifestFileLocation manifestFileLocation) {
            this.manifestFileLocation = manifestFileLocation;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link QuicksightDataSourceParametersS3}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public QuicksightDataSourceParametersS3 build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link QuicksightDataSourceParametersS3}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements QuicksightDataSourceParametersS3 {
        private final com.hashicorp.cdktf.providers.aws.quicksight_data_source.QuicksightDataSourceParametersS3ManifestFileLocation manifestFileLocation;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.manifestFileLocation = software.amazon.jsii.Kernel.get(this, "manifestFileLocation", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.quicksight_data_source.QuicksightDataSourceParametersS3ManifestFileLocation.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.manifestFileLocation = java.util.Objects.requireNonNull(builder.manifestFileLocation, "manifestFileLocation is required");
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.quicksight_data_source.QuicksightDataSourceParametersS3ManifestFileLocation getManifestFileLocation() {
            return this.manifestFileLocation;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("manifestFileLocation", om.valueToTree(this.getManifestFileLocation()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.quicksightDataSource.QuicksightDataSourceParametersS3"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            QuicksightDataSourceParametersS3.Jsii$Proxy that = (QuicksightDataSourceParametersS3.Jsii$Proxy) o;

            return this.manifestFileLocation.equals(that.manifestFileLocation);
        }

        @Override
        public final int hashCode() {
            int result = this.manifestFileLocation.hashCode();
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/quicksight_data_source/QuicksightDataSourceParametersS3.java <==
package com.hashicorp.cdktf.providers.aws.quicksight_data_source;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:11.228Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.quicksightDataSource.QuicksightDataSourceParametersS3")
@software.amazon.jsii.Jsii.Proxy(QuicksightDataSourceParametersS3.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface QuicksightDataSourceParametersS3 extends software.amazon.jsii.JsiiSerializable {

    /**
     * manifest_file_location block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/quicksight_data_source#manifest_file_location QuicksightDataSource#manifest_file_location}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.quicksight_data_source.QuicksightDataSourceParametersS3ManifestFileLocation getManifestFileLocation();

    /**
     * @return a {@link Builder} of {@link QuicksightDataSourceParametersS3}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link QuicksightDataSourceParametersS3}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<QuicksightDataSourceParametersS3> {
        com.hashicorp.cdktf.providers.aws.quicksight_data_source.QuicksightDataSourceParametersS3ManifestFileLocation manifestFileLocation;

        /**
         * Sets the value of {@link QuicksightDataSourceParametersS3#getManifestFileLocation}
         * @param manifestFileLocation manifest_file_location block. This parameter is required.
         *                             Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/quicksight_data_source#manifest_file_location QuicksightDataSource#manifest_file_location}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder manifestFileLocation(com.hashicorp.cdktf.providers.aws.quicksight_data_source.QuicksightDataSourceParametersS3ManifestFileLocation manifestFileLocation) {
            this.manifestFileLocation = manifestFileLocation;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link QuicksightDataSourceParametersS3}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public QuicksightDataSourceParametersS3 build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link QuicksightDataSourceParametersS3}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements QuicksightDataSourceParametersS3 {
        private final com.hashicorp.cdktf.providers.aws.quicksight_data_source.QuicksightDataSourceParametersS3ManifestFileLocation manifestFileLocation;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.manifestFileLocation = software.amazon.jsii.Kernel.get(this, "manifestFileLocation", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.quicksight_data_source.QuicksightDataSourceParametersS3ManifestFileLocation.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.manifestFileLocation = java.util.Objects.requireNonNull(builder.manifestFileLocation, "manifestFileLocation is required");
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.quicksight_data_source.QuicksightDataSourceParametersS3ManifestFileLocation getManifestFileLocation() {
            return this.manifestFileLocation;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("manifestFileLocation", om.valueToTree(this.getManifestFileLocation()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.quicksightDataSource.QuicksightDataSourceParametersS3"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            QuicksightDataSourceParametersS3.Jsii$Proxy that = (QuicksightDataSourceParametersS3.Jsii$Proxy) o;

            return this.manifestFileLocation.equals(that.manifestFileLocation);
        }

        @Override
        public final int hashCode() {
            int result = this.manifestFileLocation.hashCode();
            return result;
        }
    }
}
